@@ -25,7 +25,9 @@ class LanguageTreeNode(AbstractTreeNode):
     visible = models.BooleanField(
         default=True,
         verbose_name=_("visible"),
-        help_text=_("Defined if this language should be delivered via the API"),
+        help_text=_(
+            "Defines whether the language is displayed to the users of the app"
+        ),
     )
     active = models.BooleanField(
         default=True,
