@@ -7,11 +7,13 @@ from django.urls import include, path
 
 from ..forms import (
     LanguageForm,
+    LanguageTreeNodeForm,
     OfferTemplateForm,
     OrganizationForm,
     RegionForm,
     EventTranslationForm,
     POITranslationForm,
+    PageTranslationForm,
 )
 from ..models import Event, Language, OfferTemplate, Organization, Page, POI, Role
 
@@ -304,44 +306,6 @@ urlpatterns = [
             ]
         ),
     ),
-    path(
-        "organizations/",
-        include(
-            [
-                path(
-                    "",
-                    list_views.ModelListView.as_view(model=Organization),
-                    name="organizations",
-                ),
-                path(
-                    "new/",
-                    form_views.CustomCreateView.as_view(form_class=OrganizationForm),
-                    name="new_organization",
-                ),
-                path(
-                    "<slug>/",
-                    include(
-                        [
-                            path(
-                                "edit/",
-                                form_views.CustomUpdateView.as_view(
-                                    form_class=OrganizationForm
-                                ),
-                                name="edit_organization",
-                            ),
-                            path(
-                                "delete/",
-                                delete_views.CustomDeleteView.as_view(
-                                    model=Organization,
-                                ),
-                                name="delete_organization",
-                            ),
-                        ]
-                    ),
-                ),
-            ]
-        ),
-    ),
     path(
         "feedback/",
         include(
@@ -622,11 +586,6 @@ urlpatterns = [
                     "analytics/",
                     include(
                         [
-                            path(
-                                "",
-                                analytics.AnalyticsView.as_view(),
-                                name="analytics",
-                            ),
                             path(
                                 "statistics/",
                                 statistics.AnalyticsView.as_view(),
@@ -744,7 +703,7 @@ urlpatterns = [
                                             "bulk-archive/",
                                             bulk_action_views.BulkArchiveView.as_view(
                                                 model=Page,
-                                                archived_field="explicitly_archived",
+                                                field_name="explicitly_archived",
                                             ),
                                             name="bulk_archive_pages",
                                         ),
@@ -752,10 +711,18 @@ urlpatterns = [
                                             "bulk-restore/",
                                             bulk_action_views.BulkRestoreView.as_view(
                                                 model=Page,
-                                                archived_field="explicitly_archived",
+                                                field_name="explicitly_archived",
                                             ),
                                             name="bulk_restore_pages",
                                         ),
+                                        path(
+                                            "auto-translate-easy-german/",
+                                            bulk_action_views.BulkActionEasyGermanView.as_view(
+                                                model=Page,
+                                                form=PageTranslationForm,
+                                            ),
+                                            name="auto_translate_easy_german_pages",
+                                        ),
                                         path(
                                             "<int:page_id>/",
                                             include(
@@ -887,6 +854,46 @@ urlpatterns = [
                         ]
                     ),
                 ),
+                path(
+                    "organizations/",
+                    include(
+                        [
+                            path(
+                                "",
+                                list_views.ModelListView.as_view(model=Organization),
+                                name="organizations",
+                            ),
+                            path(
+                                "new/",
+                                form_views.CustomCreateView.as_view(
+                                    form_class=OrganizationForm
+                                ),
+                                name="new_organization",
+                            ),
+                            path(
+                                "<slug>/",
+                                include(
+                                    [
+                                        path(
+                                            "edit/",
+                                            form_views.CustomUpdateView.as_view(
+                                                form_class=OrganizationForm
+                                            ),
+                                            name="edit_organization",
+                                        ),
+                                        path(
+                                            "delete/",
+                                            delete_views.CustomDeleteView.as_view(
+                                                model=Organization,
+                                            ),
+                                            name="delete_organization",
+                                        ),
+                                    ]
+                                ),
+                            ),
+                        ]
+                    ),
+                ),
                 # TODO: Change destination for delete_event, add view_event
                 path(
                     "events/",
@@ -919,6 +926,14 @@ urlpatterns = [
                                             ),
                                             name="automatic_translation_events",
                                         ),
+                                        path(
+                                            "auto-translate-easy-german/",
+                                            bulk_action_views.BulkActionEasyGermanView.as_view(
+                                                model=Event,
+                                                form=EventTranslationForm,
+                                            ),
+                                            name="auto_translate_easy_german_events",
+                                        ),
                                         path(
                                             "bulk-archive/",
                                             bulk_action_views.BulkArchiveView.as_view(
@@ -1002,6 +1017,14 @@ urlpatterns = [
                                             ),
                                             name="automatic_translation_pois",
                                         ),
+                                        path(
+                                            "auto-translate-easy-german/",
+                                            bulk_action_views.BulkActionEasyGermanView.as_view(
+                                                model=POI,
+                                                form=POITranslationForm,
+                                            ),
+                                            name="auto_translate_easy_german_pois",
+                                        ),
                                         path(
                                             "bulk-archive/",
                                             bulk_action_views.BulkArchiveView.as_view(
@@ -1129,32 +1152,54 @@ urlpatterns = [
                             path(
                                 "",
                                 language_tree.LanguageTreeView.as_view(),
-                                name="language_tree",
+                                name="languagetreenodes",
                             ),
                             path(
                                 "new/",
-                                language_tree.LanguageTreeNodeFormView.as_view(),
-                                name="new_language_tree_node",
+                                language_tree.LanguageTreeNodeCreateView.as_view(),
+                                name="new_languagetreenode",
                             ),
                             path(
-                                "<int:language_tree_node_id>/",
+                                "bulk-make-visible/",
+                                language_tree.BulkMakeVisibleView.as_view(),
+                                name="bulk_make_languagetreenodes_visible",
+                            ),
+                            path(
+                                "bulk-hide/",
+                                language_tree.BulkHideView.as_view(),
+                                name="bulk_hide_languagetreenodes",
+                            ),
+                            path(
+                                "bulk-activate/",
+                                language_tree.BulkActivateView.as_view(),
+                                name="bulk_activate_languagetreenodes",
+                            ),
+                            path(
+                                "bulk-disable/",
+                                language_tree.BulkDisableView.as_view(),
+                                name="bulk_disable_languagetreenodes",
+                            ),
+                            path(
+                                "<int:pk>/",
                                 include(
                                     [
                                         path(
                                             "edit/",
-                                            language_tree.LanguageTreeNodeFormView.as_view(),
-                                            name="edit_language_tree_node",
+                                            form_views.CustomUpdateView.as_view(
+                                                form_class=LanguageTreeNodeForm
+                                            ),
+                                            name="edit_languagetreenode",
                                         ),
                                         path(
                                             "delete/",
                                             language_tree.delete_language_tree_node,
-                                            name="delete_language_tree_node",
+                                            name="delete_languagetreenode",
                                         ),
                                         # warning: the move url is also hardcoded in src/integreat_cms/static/js/tree_drag_and_drop.js
                                         path(
                                             "move/<int:target_id>/<slug:target_position>/",
                                             language_tree.move_language_tree_node,
-                                            name="move_language_tree_node",
+                                            name="move_languagetreenode",
                                         ),
                                     ]
                                 ),
