@@ -34,10 +34,7 @@ class POIFormView(
     #: The template to render (see :class:`~django.views.generic.base.TemplateResponseMixin`)
     template_name = "pois/poi_form.html"
     #: The context dict passed to the template (see :class:`~django.views.generic.base.ContextMixin`)
-    extra_context = {
-        "current_menu_item": "pois_form",
-        "PUBLIC": status.PUBLIC,
-    }
+    extra_context = {"current_menu_item": "pois_form"}
     #: The url name of the view to show if the user decides to go back (see :class:`~integreat_cms.cms.views.mixins.ContentEditLockMixin`)
     back_url_name = "pois"
 
