@@ -8,10 +8,10 @@ from django.utils.decorators import method_decorator
 from django.utils.translation import ugettext as _
 from django.views.generic import TemplateView
 
-from ...constants import status
 from ...decorators import permission_required
 from ...models import POITranslation
 from ...forms import ObjectSearchForm
+from ..mixins import SummAiContextMixin
 from .poi_context_mixin import POIContextMixin
 
 from ....deepl_api.utils import DeepLApi
@@ -20,7 +20,7 @@ logger = logging.getLogger(__name__)
 
 
 @method_decorator(permission_required("cms.view_poi"), name="dispatch")
-class POIListView(TemplateView, POIContextMixin):
+class POIListView(TemplateView, POIContextMixin, SummAiContextMixin):
     """
     View for listing POIs (points of interests)
     """
@@ -30,12 +30,7 @@ class POIListView(TemplateView, POIContextMixin):
     #: Template for list of archived POIs
     template_archived = "pois/poi_list_archived.html"
     #: The context dict passed to the template (see :class:`~django.views.generic.base.ContextMixin`)
-    extra_context = {
-        "current_menu_item": "pois",
-        "WEBAPP_URL": settings.WEBAPP_URL,
-        "PUBLIC": status.PUBLIC,
-        "DEEPL_ENABLED": settings.DEEPL_ENABLED,
-    }
+    extra_context = {"current_menu_item": "pois"}
     #: Whether or not to show archived POIs
     archived = False
 
