@@ -16,7 +16,7 @@ from django.core.exceptions import ImproperlyConfigured
 from django.utils.translation import ugettext_lazy as _
 
 from ..nominatim_api.utils import BoundingBox
-from .logging_formatter import ColorFormatter
+from .logging_formatter import ColorFormatter, RequestFormatter
 
 
 ###################
@@ -109,6 +109,11 @@ DEFAULT_BOUNDING_BOX = BoundingBox(
     longitude_max=15.0169958839,
 )
 
+#: The default timeout in seconds for retrieving external APIs etc.
+DEFAULT_REQUEST_TIMEOUT = int(
+    os.environ.get("INTEGREAT_CMS_DEFAULT_REQUEST_TIMEOUT", 10)
+)
+
 
 ###############################
 # Firebase Push Notifications #
@@ -198,6 +203,7 @@ INSTALLED_APPS = [
     "integreat_cms.gvz_api",
     "integreat_cms.deepl_api",
     "integreat_cms.nominatim_api",
+    "integreat_cms.summ_ai_api",
     "integreat_cms.linkcheck.apps.ModifiedLinkcheckConfig",
     # Installed Django apps
     "django.contrib.auth",
@@ -263,8 +269,8 @@ TEMPLATES = [
                 "django.contrib.auth.context_processors.auth",
                 "django.contrib.messages.context_processors.messages",
                 "integreat_cms.core.context_processors.version_processor",
-                "integreat_cms.core.context_processors.push_notification_processor",
-                "integreat_cms.core.context_processors.branding_processor",
+                "integreat_cms.core.context_processors.settings_processor",
+                "integreat_cms.core.context_processors.constants_processor",
             ],
             "debug": DEBUG,
         },
@@ -423,6 +429,7 @@ LOGGING = {
     "disable_existing_loggers": False,
     "formatters": {
         "console": {
+            "()": RequestFormatter,
             "format": "{asctime} \x1b[1m{levelname}\x1b[0m {name} - {message}",
             "datefmt": "%b %d %H:%M:%S",
             "style": "{",
@@ -434,6 +441,7 @@ LOGGING = {
             "style": "{",
         },
         "logfile": {
+            "()": RequestFormatter,
             "format": "{asctime} {levelname:7} {name} - {message}",
             "datefmt": "%b %d %H:%M:%S",
             "style": "{",
@@ -604,12 +612,30 @@ EMAIL_USE_SSL = bool(strtobool(os.environ.get("INTEGREAT_CMS_EMAIL_USE_SSL", "Fa
 # INTERNATIONALIZATION #
 ########################
 
-#: A list of all available languages (see :setting:`django:LANGUAGES` and :doc:`django:topics/i18n/index`)
-LANGUAGES = (
-    ("de", _("German")),
-    ("en", _("English")),
-    ("nl", _("Dutch")),
-)
+#: A list of all available languages with locale files for translated strings
+AVAILABLE_LANGUAGES = {
+    "de": _("German"),
+    "en": _("English"),
+    "nl": _("Dutch"),
+}
+
+#: The default UI languages
+DEFAULT_LANGUAGES = ["de", "en"]
+
+#: The list of languages which are available in the UI
+#: (see :setting:`django:LANGUAGES` and :doc:`django:topics/i18n/index`)
+LANGUAGES = [
+    (language, AVAILABLE_LANGUAGES[language])
+    for language in filter(
+        None,
+        (
+            language.strip()
+            for language in os.environ.get(
+                "INTEGREAT_CMS_LANGUAGES", "\n".join(DEFAULT_LANGUAGES)
+            ).splitlines()
+        ),
+    )
+]
 
 #: A list of directories where Django looks for translation files
 #: (see :setting:`django:LOCALE_PATHS` and :doc:`django:topics/i18n/index`)
@@ -617,7 +643,7 @@ LOCALE_PATHS = (os.path.join(BASE_DIR, "locale"),)
 
 #: A string representing the language slug for this installation
 #: (see :setting:`django:LANGUAGE_CODE` and :doc:`django:topics/i18n/index`)
-LANGUAGE_CODE = "de"
+LANGUAGE_CODE = os.environ.get("INTEGREAT_CMS_LANGUAGE_CODE", "de")
 
 #: A string representing the time zone for this installation
 #: (see :setting:`django:TIME_ZONE` and :doc:`django:topics/i18n/index`)
@@ -651,6 +677,57 @@ DEEPL_AUTH_KEY = os.environ.get("INTEGREAT_CMS_DEEPL_AUTH_KEY")
 DEEPL_ENABLED = bool(DEEPL_AUTH_KEY)
 
 
+#########################
+# SUMM.AI - EASY GERMAN #
+#########################
+
+#: The URL to our SUMM.AI API for automatic translations from German into Easy German
+SUMM_AI_API_URL = os.environ.get(
+    "INTEGREAT_CMS_SUMM_AI_API_URL", "https://backend.summ-ai.com/translate/v1/"
+)
+
+#: Authentication token for SUMM.AI,
+#: If not set, automatic translations to easy german are disabled
+SUMM_AI_API_KEY = os.environ.get("INTEGREAT_CMS_SUMM_AI_API_KEY")
+
+#: Whether SUMM.AI is enabled or not
+#: This is ``True`` if SUMM_AI_API_KEY is set, ``False`` otherwise.
+SUMM_AI_ENABLED = bool(SUMM_AI_API_KEY)
+
+#: Whether requests to the SUMM.AI are done with the ``is_test`` flag
+SUMM_AI_TEST_MODE = strtobool(
+    os.environ.get("INTEGREAT_CMS_SUMM_AI_TEST_MODE", str(DEBUG))
+)
+
+#: The timeout in minutes for requests to the SUMM.AI API
+SUMM_AI_TIMEOUT = 10
+
+#: The language slugs for German
+SUMM_AI_GERMAN_LANGUAGE_SLUG = os.environ.get(
+    "INTEGREAT_CMS_SUMM_AI_GERMAN_LANGUAGE_SLUG", "de"
+)
+
+#: The language slug for Easy German
+SUMM_AI_EASY_GERMAN_LANGUAGE_SLUG = os.environ.get(
+    "INTEGREAT_CMS_SUMM_AI_EASY_GERMAN_LANGUAGE_SLUG", "de-si"
+)
+
+#: The separator which is used to split compound words, e.g. Bundes-Kanzler (hyphen) or Bundes·kanzler (interpunct)
+SUMM_AI_SEPARATOR = os.environ.get("INTEGREAT_CMS_SUMM_AI_SEPARATOR", "hyphen")
+
+#: All plain text fields of the content models which should be translated
+SUMM_AI_TEXT_FIELDS = ["short_description"]
+
+#: All HTML fields of the content models which should be translated
+SUMM_AI_HTML_FIELDS = ["content"]
+
+#: All fields of the content models which should not be translated, but inherited from the source translation
+SUMM_AI_INHERITED_FIELDS = ["title"]
+
+#: Translate all <p> and <li> tags
+SUMM_AI_HTML_TAGS = ["p", "li"]
+
+
 ################
 # STATIC FILES #
 ################
