@@ -139,7 +139,9 @@ def page_to_xliff(page, target_language, dir_name, only_public=False):
     if only_public:
         target_page_translation = page.get_public_translation(target_language.slug)
     else:
-        target_page_translation = page.get_translation(target_language.slug)
+        target_page_translation = page.get_public_or_draft_translation(
+            target_language.slug
+        )
     if not target_page_translation:
         # Create temporary target translation
         target_page_translation = PageTranslation(
@@ -149,7 +151,7 @@ def page_to_xliff(page, target_language, dir_name, only_public=False):
     source_translation = (
         target_page_translation.public_source_translation
         if only_public
-        else target_page_translation.source_translation
+        else target_page_translation.public_or_draft_source_translation
     )
     if not source_translation:
         source_language = page.region.get_source_language(target_language.slug)
@@ -189,7 +191,7 @@ def page_to_xliff(page, target_language, dir_name, only_public=False):
                 _("An unexpected error has occurred while exporting page {}.").format(
                     target_page_translation.readable_title
                 ),
-                _("Please try again or contact the administrator."),
+                _("Please try again later or contact an administrator."),
             )
         ) from e
 
@@ -276,7 +278,7 @@ def xliffs_to_pages(request, xliff_dir):
                         _(
                             'An unexpected error has occurred while importing XLIFF file "{}".'
                         ).format(xliff_file_path_rel),
-                        _("Please try again or contact the administrator."),
+                        _("Please try again later or contact an administrator."),
                     ),
                 )
     # Store deserialized objects in cache
