@@ -4,6 +4,8 @@ This modules contains the config for the view tests
 from django.conf import settings
 from django.urls import reverse
 
+from integreat_cms.cms.constants import status
+
 from ...conftest import (
     ALL_ROLES,
     AUTHOR,
@@ -35,12 +37,10 @@ VIEWS = [
             ("mediacenter_get_directory_content", STAFF_ROLES),
             ("new_language", STAFF_ROLES),
             ("new_offertemplate", STAFF_ROLES),
-            ("new_organization", STAFF_ROLES),
             ("new_region", STAFF_ROLES),
             ("new_role", [ROOT]),
             ("new_user", STAFF_ROLES),
             ("offertemplates", STAFF_ROLES),
-            ("organizations", STAFF_ROLES),
             ("regions", STAFF_ROLES),
             ("roles", [ROOT]),
             ("user_settings", STAFF_ROLES),
@@ -52,15 +52,14 @@ VIEWS = [
     ),
     (
         [
-            ("analytics", ROLES),
             ("dashboard", ROLES),
-            ("language_tree", STAFF_ROLES),
+            ("languagetreenodes", STAFF_ROLES),
             ("media", ROLES),
             ("mediacenter_directory_path", ROLES),
             ("mediacenter_get_directory_content", ROLES),
-            ("new_language_tree_node", STAFF_ROLES),
+            ("new_languagetreenode", STAFF_ROLES),
             (
-                "new_language_tree_node",
+                "new_languagetreenode",
                 HIGH_PRIV_STAFF_ROLES,
                 {
                     "language": 5,
@@ -71,6 +70,26 @@ VIEWS = [
                     "active": True,
                 },
             ),
+            (
+                "bulk_make_languagetreenodes_visible",
+                HIGH_PRIV_STAFF_ROLES,
+                {"selected_ids[]": [1, 2, 3]},
+            ),
+            (
+                "bulk_hide_languagetreenodes",
+                HIGH_PRIV_STAFF_ROLES,
+                {"selected_ids[]": [1, 2, 3]},
+            ),
+            (
+                "bulk_activate_languagetreenodes",
+                HIGH_PRIV_STAFF_ROLES,
+                {"selected_ids[]": [1, 2, 3]},
+            ),
+            (
+                "bulk_disable_languagetreenodes",
+                HIGH_PRIV_STAFF_ROLES,
+                {"selected_ids[]": [1, 2, 3]},
+            ),
             ("new_region_user", STAFF_ROLES + [MANAGEMENT]),
             (
                 "new_region_user",
@@ -80,6 +99,8 @@ VIEWS = [
             ("region_feedback", STAFF_ROLES + [MANAGEMENT]),
             ("region_users", STAFF_ROLES + [MANAGEMENT]),
             ("translation_coverage", ROLES),
+            ("organizations", STAFF_ROLES),
+            ("new_organization", STAFF_ROLES),
             ("user_settings", ROLES),
             ("authenticate_modify_mfa", ROLES),
         ],
@@ -88,15 +109,14 @@ VIEWS = [
     ),
     (
         [
-            ("analytics", STAFF_ROLES),
             ("dashboard", STAFF_ROLES),
-            ("language_tree", STAFF_ROLES),
+            ("languagetreenodes", STAFF_ROLES),
             ("media", STAFF_ROLES),
             ("mediacenter_directory_path", STAFF_ROLES),
             ("mediacenter_get_directory_content", STAFF_ROLES),
-            ("new_language_tree_node", STAFF_ROLES),
+            ("new_languagetreenode", STAFF_ROLES),
             (
-                "new_language_tree_node",
+                "new_languagetreenode",
                 HIGH_PRIV_STAFF_ROLES,
                 {
                     "language": 5,
@@ -115,6 +135,8 @@ VIEWS = [
             ),
             ("region_feedback", STAFF_ROLES),
             ("region_users", STAFF_ROLES),
+            ("organizations", STAFF_ROLES),
+            ("new_organization", STAFF_ROLES),
             ("translation_coverage", STAFF_ROLES),
             ("user_settings", STAFF_ROLES),
             ("authenticate_modify_mfa", STAFF_ROLES),
@@ -131,7 +153,7 @@ VIEWS = [
             (
                 "edit_imprint",
                 PRIV_STAFF_ROLES + [MANAGEMENT],
-                {"title": "imprint", "submit_draft": True},
+                {"title": "imprint", "status": status.DRAFT},
             ),
             ("events", ROLES),
             ("events_archived", ROLES),
@@ -144,7 +166,7 @@ VIEWS = [
                     "start_date": "2030-01-01",
                     "end_date": "2030-01-01",
                     "is_all_day": True,
-                    "submit_draft": True,
+                    "status": status.DRAFT,
                 },
             ),
             ("new_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
@@ -156,7 +178,7 @@ VIEWS = [
                     "mirrored_page_region": "",
                     "_ref_node_id": 1,
                     "_position": "first-child",
-                    "submit_draft": True,
+                    "status": status.DRAFT,
                 },
             ),
             (
@@ -167,7 +189,7 @@ VIEWS = [
                     "mirrored_page_region": "",
                     "_ref_node_id": 1,
                     "_position": "first-child",
-                    "submit_public": True,
+                    "status": status.PUBLIC,
                 },
             ),
             ("new_poi", ROLES),
@@ -183,7 +205,7 @@ VIEWS = [
                     "country": "Deutschland",
                     "longitude": 1,
                     "latitude": 1,
-                    "submit_draft": True,
+                    "status": status.DRAFT,
                 },
             ),
             ("pages", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
@@ -230,7 +252,7 @@ VIEWS = [
             (
                 "edit_imprint",
                 PRIV_STAFF_ROLES,
-                {"title": "imprint", "submit_draft": True},
+                {"title": "imprint", "status": status.DRAFT},
             ),
             ("events", STAFF_ROLES),
             ("events_archived", STAFF_ROLES),
@@ -243,7 +265,7 @@ VIEWS = [
                     "start_date": "2030-01-01",
                     "end_date": "2030-01-01",
                     "is_all_day": True,
-                    "submit_draft": True,
+                    "status": status.DRAFT,
                 },
             ),
             ("new_page", STAFF_ROLES),
@@ -255,7 +277,7 @@ VIEWS = [
                     "mirrored_page_region": "",
                     "_ref_node_id": 7,
                     "_position": "first-child",
-                    "submit_draft": True,
+                    "status": status.DRAFT,
                 },
             ),
             ("new_poi", STAFF_ROLES),
@@ -271,7 +293,7 @@ VIEWS = [
                     "country": "Deutschland",
                     "longitude": 1,
                     "latitude": 1,
-                    "submit_draft": True,
+                    "status": status.DRAFT,
                 },
             ),
             ("pages", STAFF_ROLES),
@@ -388,6 +410,120 @@ VIEWS = [
         # The kwargs for these views
         {"region_slug": "nurnberg", "parent_id": 7},
     ),
+    (
+        [
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR],
+                {"revision": 1, "status": status.REVIEW},
+            ),
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
+                {"revision": 1, "status": status.PUBLIC},
+            ),
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
+                {"revision": 1, "status": status.DRAFT},
+            ),
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
+                {"revision": 2, "status": status.PUBLIC},
+            ),
+        ],
+        # The kwargs for these views
+        {"region_slug": "augsburg", "language_slug": "de", "page_id": 1},
+    ),
+    (
+        [
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR],
+                {"revision": 1, "status": status.REVIEW},
+            ),
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
+                {"revision": 1, "status": status.PUBLIC},
+            ),
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
+                {"revision": 1, "status": status.DRAFT},
+            ),
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
+                {"revision": 2, "status": status.PUBLIC},
+            ),
+        ],
+        # The kwargs for these views
+        {"region_slug": "augsburg", "language_slug": "de", "page_id": 3},
+    ),
+    (
+        [
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR],
+                {"revision": 1, "status": status.REVIEW},
+            ),
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
+                {"revision": 1, "status": status.PUBLIC},
+            ),
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
+                {"revision": 1, "status": status.DRAFT},
+            ),
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
+                {"revision": 2, "status": status.PUBLIC},
+            ),
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
+                {"revision": 2},
+            ),
+        ],
+        # The kwargs for these views
+        {"region_slug": "augsburg", "language_slug": "de", "page_id": 14},
+    ),
+    (
+        [
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR],
+                {"revision": 1, "status": status.REVIEW},
+            ),
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
+                {"revision": 1, "status": status.PUBLIC},
+            ),
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
+                {"revision": 1, "status": status.DRAFT},
+            ),
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
+                {"revision": 2, "status": status.PUBLIC},
+            ),
+            (
+                "page_revisions",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
+                {"revision": 2},
+            ),
+        ],
+        # The kwargs for these views
+        {"region_slug": "augsburg", "language_slug": "de", "page_id": 15},
+    ),
     (
         [("get_page_order_table_ajax", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR])],
         # The kwargs for these views
@@ -422,6 +558,17 @@ VIEWS = [
         [
             ("edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
             ("edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
+            (
+                "edit_page",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR],
+                {
+                    "title": "new title",
+                    "mirrored_page_region": "",
+                    "_ref_node_id": 21,
+                    "_position": "first-child",
+                    "status": status.REVIEW,
+                },
+            ),
             (
                 "edit_page",
                 PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
@@ -430,7 +577,7 @@ VIEWS = [
                     "mirrored_page_region": "",
                     "_ref_node_id": 21,
                     "_position": "first-child",
-                    "submit_draft": True,
+                    "status": status.DRAFT,
                 },
             ),
             (
@@ -441,7 +588,7 @@ VIEWS = [
                     "mirrored_page_region": "",
                     "_ref_node_id": 24,  # Archived ref node
                     "_position": "right",
-                    "submit_draft": True,
+                    "status": status.DRAFT,
                 },
             ),
             (
@@ -452,7 +599,7 @@ VIEWS = [
                     "mirrored_page_region": "",
                     "_ref_node_id": 21,
                     "_position": "first-child",
-                    "submit_public": True,
+                    "status": status.PUBLIC,
                 },
             ),
             ("sbs_edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
@@ -472,6 +619,48 @@ VIEWS = [
         # The kwargs for these views
         {"region_slug": "augsburg", "language_slug": "en", "page_id": 1},
     ),
+    (
+        [
+            ("edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
+            ("edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
+            (
+                "edit_page",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR],
+                {
+                    "title": "new title",
+                    "mirrored_page_region": "",
+                    "_ref_node_id": 3,
+                    "_position": "first-child",
+                    "status": status.REVIEW,
+                },
+            ),
+            (
+                "edit_page",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
+                {
+                    "title": "new title",
+                    "mirrored_page_region": "",
+                    "_ref_node_id": 3,
+                    "_position": "first-child",
+                    "status": status.DRAFT,
+                },
+            ),
+            (
+                "edit_page",
+                PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
+                {
+                    "title": "new title",
+                    "mirrored_page_region": "",
+                    "_ref_node_id": 3,
+                    "_position": "first-child",
+                    "status": status.PUBLIC,
+                },
+            ),
+            ("sbs_edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
+        ],
+        # The kwargs for these views
+        {"region_slug": "augsburg", "language_slug": "en", "page_id": 2},
+    ),
     (
         [
             ("edit_page", STAFF_ROLES),
@@ -522,7 +711,7 @@ VIEWS = [
                     "start_date": "2030-01-01",
                     "end_date": "2030-01-01",
                     "is_all_day": True,
-                    "submit_draft": True,
+                    "status": status.DRAFT,
                 },
             ),
             ("archive_event", PRIV_STAFF_ROLES + REGION_ROLES, {"post_data": True}),
@@ -547,7 +736,7 @@ VIEWS = [
                     "country": "Deutschland",
                     "longitude": 1,
                     "latitude": 1,
-                    "submit_draft": True,
+                    "status": status.DRAFT,
                 },
             ),
             ("archive_poi", PRIV_STAFF_ROLES + REGION_ROLES, {"post_data": True}),
@@ -559,9 +748,9 @@ VIEWS = [
     ),
     (
         [
-            ("edit_language_tree_node", STAFF_ROLES),
+            ("edit_languagetreenode", STAFF_ROLES),
             (
-                "edit_language_tree_node",
+                "edit_languagetreenode",
                 HIGH_PRIV_STAFF_ROLES,
                 {
                     "language": 3,
@@ -572,7 +761,7 @@ VIEWS = [
             ),
         ],
         # The kwargs for these views
-        {"region_slug": "augsburg", "language_tree_node_id": 3},
+        {"region_slug": "augsburg", "pk": 3},
     ),
     (
         [
@@ -627,7 +816,7 @@ if settings.FCM_ENABLED:
                         "form-0-language": 1,
                         "form-1-title": "",
                         "form-1-text": "",
-                        "form-1-language": 2,
+                        "form-1-language": 6,
                         "channel": "news",
                         "mode": "ONLY_AVAILABLE",
                     },
